summaryrefslogtreecommitdiff
path: root/tests/unit/misc/test_utilcmds.py
diff options
context:
space:
mode:
Diffstat (limited to 'tests/unit/misc/test_utilcmds.py')
-rw-r--r--tests/unit/misc/test_utilcmds.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/unit/misc/test_utilcmds.py b/tests/unit/misc/test_utilcmds.py
index 674f046c7..96bc8da42 100644
--- a/tests/unit/misc/test_utilcmds.py
+++ b/tests/unit/misc/test_utilcmds.py
@@ -12,17 +12,17 @@ from qutebrowser.api import cmdutils
from qutebrowser.utils import objreg
-def test_repeat_command_initial(mocker, mode_manager):
+def test_cmd_repeat_last_initial(mocker, mode_manager):
"""Test repeat_command first-time behavior.
If :repeat-command is called initially, it should err, because there's
nothing to repeat.
"""
objreg_mock = mocker.patch('qutebrowser.misc.utilcmds.objreg')
objreg_mock.get.return_value = mode_manager
with pytest.raises(cmdutils.CommandError,
match="You didn't do anything yet."):
- utilcmds.repeat_command(win_id=0)
+ utilcmds.cmd_repeat_last(win_id=0)
class FakeWindow:
@@ -12,17 +12,17 @@ from qutebrowser.api import cmdutils
"""Test repeat_command first-time behavior.
- If :repeat-command is called initially, it should err, because there's
+ If :cmd-repeat-last is called initially, it should err, because there's
nothing to repeat.
"""